"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "useCopilotMessage_unstable", {
    enumerable: true,
    get: function() {
        return useCopilotMessage_unstable;
    }
});
const _interop_require_wildcard = require("@swc/helpers/_/_interop_require_wildcard");
const _react = /*#__PURE__*/ _interop_require_wildcard._(require("react"));
const _reactcomponents = require("@fluentui/react-components");
const _reactsharedcontexts = require("@fluentui/react-shared-contexts");
const _reactutilities = require("@fluentui/react-utilities");
const _reactoutputcard = require("@fluentui-copilot/react-output-card");
const _useMessageAttributes = require("../../utils/useMessageAttributes");
const useCopilotMessage_unstable = (props, ref)=>{
    const { announcement, accessibleHeading, isLoading } = props;
    const cardState = (0, _reactoutputcard.useOutputCard_unstable)(props, ref);
    const id = (0, _reactcomponents.useId)('copilot-message-', props.id);
    const rootRef = _react.useRef(null);
    const { announce } = (0, _reactsharedcontexts.useAnnounce_unstable)();
    // timeout for announcing "loading" at 10s intervals
    const [setLoadingAnnounceTimeout, clearLoadingAnnounceTimeout] = (0, _reactutilities.useTimeout)();
    // track whether the message has loading; this should only change once from false -> true
    const hasLoaded = _react.useRef(!isLoading);
    // if the message is loading when first mounted, kick off loading announcements
    const isFirstMount = (0, _reactutilities.useFirstMount)();
    if (isFirstMount && !announcement && isLoading) {
        const announceLoading = ()=>{
            // check for the announcement when this function runs as well
            if (!announcement) {
                announce('loading...', {
                    batchId: id
                });
            }
            setLoadingAnnounceTimeout(()=>{
                announceLoading();
            }, 10000);
        };
        announceLoading();
    }
    // fire tabster event on first mount to focus new message when it appears
    _react.useEffect(()=>{
        if (isFirstMount) {
            var _rootRef_current;
            const tabsterMoverEvent = new CustomEvent('tabster:mover:memorized-element', {
                bubbles: true,
                detail: {
                    memorizedElement: rootRef.current
                }
            });
            (_rootRef_current = rootRef.current) === null || _rootRef_current === void 0 ? void 0 : _rootRef_current.dispatchEvent(tabsterMoverEvent);
        }
    }, [
        isFirstMount
    ]);
    // announce the announcement message every time the prop changes
    _react.useEffect(()=>{
        if (announcement) {
            clearLoadingAnnounceTimeout();
            announce(announcement, {
                batchId: id
            });
        }
    }, [
        announce,
        announcement,
        clearLoadingAnnounceTimeout,
        id
    ]);
    // automatically announce when loading is complete, if announcement is not defined
    _react.useEffect(()=>{
        if (!hasLoaded.current && !isLoading) {
            // flag message as having finished loading, and stop loading announcements
            hasLoaded.current = true;
            clearLoadingAnnounceTimeout();
            if (announcement === undefined) {
                var _rootRef_current;
                const messageText = (_rootRef_current = rootRef.current) === null || _rootRef_current === void 0 ? void 0 : _rootRef_current.textContent;
                // clear any queued batched announcements and announce the full message
                announce('', {
                    batchId: id
                });
                messageText && announce(messageText);
            }
        }
    }, [
        announce,
        announcement,
        clearLoadingAnnounceTimeout,
        id,
        isLoading
    ]);
    const accessibleProps = {
        id,
        'aria-labelledby': `${id}`
    };
    return {
        ...cardState,
        components: {
            ...cardState.components,
            accessibleHeading: 'h6'
        },
        root: {
            ...cardState.root,
            ...(0, _useMessageAttributes.useMessageAttributes)({
                id,
                defaultFocused: props.defaultFocused
            }),
            ...accessibleProps,
            ref: (0, _reactcomponents.useMergedRefs)(rootRef, cardState.root.ref)
        },
        accessibleHeading: _reactcomponents.slot.optional(accessibleHeading, {
            defaultProps: {
                children: 'Copilot said: '
            },
            elementType: 'h6',
            renderByDefault: true
        })
    };
}; //# sourceMappingURL=useCopilotMessage.js.map
